import * as acm from "aws-cdk-lib/aws-certificatemanager";
import * as cloudfront from "aws-cdk-lib/aws-cloudfront";
import * as route53 from "aws-cdk-lib/aws-route53";
import * as s3 from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { CloudFrontToOriginsProps } from "./interface";
export declare class CloudFrontToOrigins extends Construct {
    readonly distribution: cloudfront.Distribution;
    readonly s3Bucket?: s3.IBucket;
    readonly originAccessIdentity?: cloudfront.OriginAccessIdentity;
    readonly logBucket?: s3.IBucket;
    readonly certificate?: acm.ICertificate;
    readonly aRecord?: route53.ARecord;
    readonly domainNames?: string[];
    constructor(scope: Construct, id: string, props: CloudFrontToOriginsProps);
    /**
     * Apply intelligent defaults based on origin configuration
     */
    private applyDefaults;
    /**
     * Defaults for S3-only static website
     */
    private getS3WebsiteDefaults;
    /**
     * Defaults for HTTP-only proxy/API
     */
    private getHttpProxyDefaults;
    /**
     * Defaults for hybrid S3 + HTTP distribution
     */
    private getHybridDefaults;
    /**
     * Setup S3 origin and bucket
     */
    private setupS3Origin;
    /**
     * Setup HTTP origin
     */
    private setupHttpOrigin;
    /**
     * Setup custom domain and certificate
     */
    private setupCustomDomain;
    /**
     * Setup CloudFront logging
     */
    private setupLogging;
    /**
     * Create CloudFront distribution
     */
    private createDistribution;
    /**
     * Setup Route53 alias record
     */
    private setupRoute53Record;
    /**
     * Get the CloudFront distribution domain name
     */
    get distributionDomainName(): string;
    /**
     * Get the CloudFront distribution URL with protocol
     */
    get distributionUrl(): string;
    /**
     * Get the custom domain URL (if configured)
     */
    get customDomainUrl(): string | undefined;
}
